==> cryptlex_python_sdk-1.0.0.tar.gz: cryptlex_python_sdk-1.0.0/src/cryptlex_web_api_client/models/postv_3_trial_activationsidextend_json_body.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="Postv3TrialActivationsidextendJsonBody")


@attr.s(auto_attribs=True)
class Postv3TrialActivationsidextendJsonBody:
    """ """

    extension_length: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        extension_length = self.extension_length

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if extension_length is not UNSET:
            field_dict["extensionLength"] = extension_length

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        extension_length = d.pop("extensionLength", UNSET)

        postv_3_trial_activationsidextend_json_body = cls(
            extension_length=extension_length,
        )

        postv_3_trial_activationsidextend_json_body.additional_properties = d
        return postv_3_trial_activationsidextend_json_body

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> cryptlex_python_sdk-1.0.3.tar.gz: cryptlex_python_sdk-1.0.3/src/cryptlex_web_api_client/models/postv_3_trial_activationsidextend_json_body.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="Postv3TrialActivationsidextendJsonBody")


@attr.s(auto_attribs=True)
class Postv3TrialActivationsidextendJsonBody:
    """
    Attributes:
        extension_length (Union[Unset, int]): Trial extension duration (in seconds) to extend the trial expiry.
    """

    extension_length: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        extension_length = self.extension_length

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if extension_length is not UNSET:
            field_dict["extensionLength"] = extension_length

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        extension_length = d.pop("extensionLength", UNSET)

        postv_3_trial_activationsidextend_json_body = cls(
            extension_length=extension_length,
        )

        postv_3_trial_activationsidextend_json_body.additional_properties = d
        return postv_3_trial_activationsidextend_json_body

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
